<?php

declare(strict_types=1);

/**
 * @copyright 2017 Christoph Wurst <christoph@winzerhof-wurst.at>
 *
 * @author 2017 Christoph Wurst <christoph@winzerhof-wurst.at>
 *
 * @license GNU AGPL version 3 or any later version
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

namespace OCA\Mail\IMAP;

use OCA\Mail\Folder;
use OCA\Mail\SearchFolder;

class MailboxPrefixDetector {

	const PREFIX = 'INBOX';

	/**
	 * @param Folder[] $folders
	 * @return bool
	 */
	public function havePrefix(array $folders): bool {
		foreach ($folders as $folder) {
			if ($folder instanceof SearchFolder) {
				// Ignore special flagged mailbox
				continue;
			}

			$parts = explode($folder->getDelimiter(), $folder->getMailbox());
			if (count($parts) < 1 || $parts[0] !== self::PREFIX) {
				return false;
			}
		}
		return true;
	}

}
